@@ -5,8 +5,9 @@ use Moose::Role;
 no warnings 'once';
 
 use JSON::Any;
+use utf8 ();
 
-our $VERSION   = '0.02';
+our $VERSION   = '0.03';
 our $AUTHORITY = 'cpan:STEVAN';
 
 requires 'pack';
@@ -15,13 +16,16 @@ requires 'unpack';
 sub thaw {
     my ( $class, $json, @args ) = @_;
     local $JSON::UnMapping = 1;
+    utf8::encode($json) if utf8::is_utf8($json);
     $class->unpack( JSON::Any->jsonToObj($json), @args );
 }
 
 sub freeze {
     my ( $self, @args ) = @_;
     local $JSON::UnMapping = 1;
-    JSON::Any->objToJson( $self->pack(@args) );
+    my $json = JSON::Any->objToJson( $self->pack(@args) );
+    utf8::decode($json) if !utf8::is_utf8($json) and utf8::valid($json); # if it's valid utf8 mark it as such
+    return $json;
 }
 
 1;
@@ -89,6 +93,8 @@ Chris Prather E<lt>chris.prather@iinteractive.comE<gt>
 
 Stevan Little E<lt>stevan.little@iinteractive.comE<gt>
 
+Yuval Kogman E<lt>yuval.kogman@iinteractive.comE<gt>
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2007 by Infinity Interactive, Inc.
